@@ -1,4 +1,4 @@
-// Copyright (C) 2016-2025 Internet Systems Consortium, Inc. ("ISC")
+// Copyright (C) 2016-2024 Internet Systems Consortium, Inc. ("ISC")
 //
 // This Source Code Form is subject to the terms of the Mozilla Public
 // License, v. 2.0. If a copy of the MPL was not distributed with this
@@ -23,13 +23,14 @@ namespace isc {
 namespace agent {
 
 CtrlAgentCfgContext::CtrlAgentCfgContext()
-    : http_host_(""), http_port_(0),
+    : http_host_(""), http_port_(0), http_headers_(),
       trust_anchor_(""), cert_file_(""), key_file_(""), cert_required_(true) {
 }
 
 CtrlAgentCfgContext::CtrlAgentCfgContext(const CtrlAgentCfgContext& orig)
     : ConfigBase(), ctrl_sockets_(orig.ctrl_sockets_),
       http_host_(orig.http_host_), http_port_(orig.http_port_),
+      http_headers_(orig.http_headers_),
       trust_anchor_(orig.trust_anchor_), cert_file_(orig.cert_file_),
       key_file_(orig.key_file_), cert_required_(orig.cert_required_),
       hooks_config_(orig.hooks_config_), auth_config_(orig.auth_config_) {
@@ -77,8 +78,8 @@ CtrlAgentCfgMgr::getConfigSummary(const uint32_t /*selection*/) {
     // Finally, print the hook libraries names
     const isc::hooks::HookLibsCollection libs = ctx->getHooksConfig().get();
     s << ", " << libs.size() << " lib(s):";
-    for (auto lib = libs.begin(); lib != libs.end(); ++lib) {
-        s << lib->first << " ";
+    for (auto const& lib : libs) {
+        s << lib.first << " ";
     }
 
     return (s.str());
@@ -163,11 +164,11 @@ CtrlAgentCfgContext::setControlSocketInfo(const ConstElementPtr& control_socket,
 std::string
 CtrlAgentCfgContext::getControlSocketInfoSummary() const {
     std::ostringstream s;
-    for (auto si = ctrl_sockets_.cbegin(); si != ctrl_sockets_.end(); ++si) {
+    for (auto const& si : ctrl_sockets_) {
         if (s.tellp() != 0) {
             s << " ";
         }
-        s << si->first;
+        s << si.first;
     }
 
     if (s.tellp() == 0) {
@@ -186,6 +187,10 @@ CtrlAgentCfgContext::toElement() const {
     ca->set("http-host", Element::create(http_host_));
     // Set http-port
     ca->set("http-port", Element::create(static_cast<int64_t>(http_port_)));
+    // Set http-headers
+    if (!http_headers_.empty()) {
+        ca->set("http-headers", CfgHttpHeaderstoElement(http_headers_));
+    }
     // Set TLS setup when enabled
     if (!trust_anchor_.empty()) {
         ca->set("trust-anchor", Element::create(trust_anchor_));
@@ -201,13 +206,9 @@ CtrlAgentCfgContext::toElement() const {
     // Set control-sockets
     ElementPtr control_sockets = Element::createMap();
     for (auto const& si : ctrl_sockets_) {
-        // Remove validated_path.
-        auto mutable_socket_info = boost::const_pointer_cast<Element>(
-                                   UserContext::toElement(si.second));
-        mutable_socket_info->remove("validated-socket-name");
-        control_sockets->set(si.first, mutable_socket_info);
+        ConstElementPtr socket = UserContext::toElement(si.second);
+        control_sockets->set(si.first, socket);
     }
-
     ca->set("control-sockets", control_sockets);
     // Set Control-agent
     ElementPtr result = Element::createMap();
