@@ -7,6 +7,7 @@
 #include <config.h>
 
 #include <agent/simple_parser.h>
+#include <asiolink/io_service_mgr.h>
 #include <cc/data.h>
 #include <cc/dhcp_config_error.h>
 #include <hooks/hooks_manager.h>
@@ -14,6 +15,7 @@
 #include <http/basic_auth_config.h>
 
 using namespace isc::data;
+using namespace isc::asiolink;
 
 namespace isc {
 namespace agent {
@@ -151,7 +153,7 @@ AgentSimpleParser::parse(const CtrlAgentCfgContextPtr& ctx,
         }
     }
 
-    // Basic HTTP authentications are forth.
+    // Basic HTTP authentications are fourth.
     ConstElementPtr auth_config = config->get("authentication");
     if (auth_config) {
         using namespace isc::http;
@@ -160,6 +162,13 @@ AgentSimpleParser::parse(const CtrlAgentCfgContextPtr& ctx,
         ctx->setAuthConfig(auth);
     }
 
+    // HTTP headers are fifth.
+    ConstElementPtr headers_config = config->get("http-headers");
+    if (headers_config) {
+        using namespace isc::http;
+        ctx->setHttpHeaders(parseCfgHttpHeaders(headers_config));
+    }
+
     // User context can be done at anytime.
     ConstElementPtr user_context = config->get("user-context");
     if (user_context) {
@@ -182,6 +191,7 @@ AgentSimpleParser::parse(const CtrlAgentCfgContextPtr& ctx,
         // change causes problems when trying to roll back.
         HooksManager::prepareUnloadLibraries();
         static_cast<void>(HooksManager::unloadLibraries());
+        IOServiceMgr::instance().clearIOServices();
         libraries.loadLibraries(false);
     }
 }
