@@ -1,4 +1,4 @@
-// Copyright (C) 2016-2025 Internet Systems Consortium, Inc. ("ISC")
+// Copyright (C) 2016-2024 Internet Systems Consortium, Inc. ("ISC")
 //
 // This Source Code Form is subject to the terms of the Mozilla Public
 // License, v. 2.0. If a copy of the MPL was not distributed with this
@@ -7,13 +7,10 @@
 #include <config.h>
 #include <agent/ca_cfg_mgr.h>
 #include <agent/parser_context.h>
-#include <config/unix_command_config.h>
 #include <exceptions/exceptions.h>
 #include <process/testutils/d_test_stubs.h>
 #include <process/d_cfg_mgr.h>
 #include <http/basic_auth_config.h>
-#include <hooks/hooks_parser.h>
-#include <util/filesystem.h>
 #include <agent/tests/test_callout_libraries.h>
 #include <agent/tests/test_data_files_config.h>
 #include <boost/pointer_cast.hpp>
@@ -25,8 +22,6 @@ using namespace isc::data;
 using namespace isc::hooks;
 using namespace isc::http;
 using namespace isc::process;
-using namespace isc::config;
-using namespace isc::util;
 
 namespace  {
 
@@ -243,8 +238,8 @@ TEST(CtrlAgentCfgMgr, contextAuthConfigFile) {
 
     auth->setRealm("foobar");
     auth->setDirectory("/tmp");
-    auth->add("", "foo", "", "bar");
-    auth->add("", "test", "", "pwd");
+    auth->add("", "/tmp/foo", "", "/tmp/bar");
+    auth->add("", "/tmp/test", "", "/tmp/pwd");
 
     const HttpAuthConfigPtr& stored_auth = ctx.getAuthConfig();
     ASSERT_TRUE(stored_auth);
@@ -269,7 +264,7 @@ const char* AGENT_CONFIGS[] = {
     "    \"http-port\": 8001,\n"
     "    \"control-sockets\": {\n"
     "        \"dhcp4\": {\n"
-    "            \"socket-name\": \"socket-v4\"\n"
+    "            \"socket-name\": \"/tmp/socket-v4\"\n"
     "        }\n"
     "    }\n"
     "}",
@@ -280,13 +275,13 @@ const char* AGENT_CONFIGS[] = {
     "    \"http-port\": 8001,\n"
     "    \"control-sockets\": {\n"
     "        \"dhcp4\": {\n"
-    "            \"socket-name\": \"socket-v4\"\n"
+    "            \"socket-name\": \"/tmp/socket-v4\"\n"
     "        },\n"
     "        \"dhcp6\": {\n"
-    "            \"socket-name\": \"socket-v6\"\n"
+    "            \"socket-name\": \"/tmp/socket-v6\"\n"
     "        },\n"
     "        \"d2\": {\n"
-    "            \"socket-name\": \"socket-d2\"\n"
+    "            \"socket-name\": \"/tmp/socket-d2\"\n"
     "        }\n"
     "   }\n"
     "}",
@@ -299,7 +294,7 @@ const char* AGENT_CONFIGS[] = {
     "    \"http-port\": 8001,\n"
     "    \"control-sockets\": {\n"
     "        \"dhcp4\": {\n"
-    "            \"socket-name\": \"socket-v4\"\n"
+    "            \"socket-name\": \"/tmp/socket-v4\"\n"
     "        }\n"
     "   },\n"
     "    \"hooks-libraries\": ["
@@ -318,7 +313,7 @@ const char* AGENT_CONFIGS[] = {
     "    \"http-port\": 8001,\n"
     "    \"control-sockets\": {\n"
     "        \"d2\": {\n"
-    "            \"socket-name\": \"socket-d2\"\n"
+    "            \"socket-name\": \"/tmp/socket-d2\"\n"
     "        }\n"
     "    }\n"
     "}",
@@ -329,7 +324,7 @@ const char* AGENT_CONFIGS[] = {
     "    \"http-port\": 8001,\n"
     "    \"control-sockets\": {\n"
     "        \"dhcp6\": {\n"
-    "            \"socket-name\": \"socket-v6\"\n"
+    "            \"socket-name\": \"/tmp/socket-v6\"\n"
     "        }\n"
     "    }\n"
     "}",
@@ -353,7 +348,7 @@ const char* AGENT_CONFIGS[] = {
     "    },\n"
     "    \"control-sockets\": {\n"
     "        \"dhcp4\": {\n"
-    "            \"socket-name\": \"socket-v4\"\n"
+    "            \"socket-name\": \"/tmp/socket-v4\"\n"
     "        }\n"
     "    }\n"
     "}",
@@ -363,6 +358,11 @@ const char* AGENT_CONFIGS[] = {
     "    \"user-context\": { \"comment\": \"Indirect comment\" },\n"
     "    \"http-host\": \"betelgeuse\",\n"
     "    \"http-port\": 8001,\n"
+    "    \"http-headers\": [ {\n"
+    "        \"comment\": \"HSTS header\",\n"
+    "        \"name\": \"Strict-Transport-Security\",\n"
+    "        \"value\": \"max-age=31536000\"\n"
+    "    } ],\n"
     "    \"authentication\": {\n"
     "        \"comment\": \"basic HTTP authentication\",\n"
     "        \"type\": \"basic\",\n"
@@ -381,10 +381,10 @@ const char* AGENT_CONFIGS[] = {
     "    \"control-sockets\": {\n"
     "        \"dhcp4\": {\n"
     "            \"comment\": \"dhcp4 socket\",\n"
-    "            \"socket-name\": \"socket-v4\"\n"
+    "            \"socket-name\": \"/tmp/socket-v4\"\n"
     "        },\n"
     "        \"dhcp6\": {\n"
-    "            \"socket-name\": \"socket-v6\",\n"
+    "            \"socket-name\": \"/tmp/socket-v6\",\n"
     "            \"user-context\": { \"version\": 1 }\n"
     "        }\n"
     "    }\n"
@@ -419,7 +419,7 @@ const char* AGENT_CONFIGS[] = {
     "    },\n"
     "    \"control-sockets\": {\n"
     "        \"dhcp4\": {\n"
-    "            \"socket-name\": \"socket-v4\"\n"
+    "            \"socket-name\": \"/tmp/socket-v4\"\n"
     "        }\n"
     "    }\n"
     "}"
@@ -428,42 +428,6 @@ const char* AGENT_CONFIGS[] = {
 /// @brief Class used for testing CfgMgr
 class AgentParserTest : public isc::process::ConfigParseTest {
 public:
-    virtual void SetUp() {
-        resetHooksPath();
-        setSocketTestPath();
-    }
-
-    virtual void TearDown() {
-        resetHooksPath();
-        resetSocketPath();
-    }
-
-    /// @brief Sets the Hooks path from which hooks can be loaded.
-    /// @param explicit_path path to use as the hooks path.
-    void setHooksTestPath(const std::string explicit_path = "") {
-        HooksLibrariesParser::getHooksPath(true,
-                                           (!explicit_path.empty() ?
-                                            explicit_path : CA_HOOKS_TEST_PATH));
-    }
-
-    /// @brief Resets the hooks path to DEFAULT_HOOKS_PATH.
-    void resetHooksPath() {
-        HooksLibrariesParser::getHooksPath(true);
-    }
-
-    /// @brief Sets the path in which the socket can be created.
-    /// @param explicit_path path to use as the socket path.
-    void setSocketTestPath(const std::string explicit_path = "") {
-        auto path = UnixCommandConfig::getSocketPath(true, (!explicit_path.empty() ?
-                                                     explicit_path : TEST_DATA_BUILDDIR));
-        UnixCommandConfig::setSocketPathPerms(file::getPermissions(path));
-    }
-
-    /// @brief Resets the socket path to the default.
-    void resetSocketPath() {
-        UnixCommandConfig::getSocketPath(true);
-        UnixCommandConfig::setSocketPathPerms();
-    }
 
     /// @brief Tries to load input text as a configuration
     ///
@@ -488,20 +452,6 @@ public:
         return (txt);
     }
 
-    /// @brief Make expected contents of socket info with socket path added.
-    ///
-    /// @param name name of the socket
-    /// @return expected string
-    std::string makeSocketStr(const std::string& name) {
-        std::ostringstream os;
-        os << "{ \"socket-name\": \""
-           << name << "\", \"socket-type\": \"unix\","
-           << " \"validated-socket-name\": \""
-           << UnixCommandConfig::getSocketPath() << "/" << name
-           << "\" }";
-        return (os.str());
-    }
-
     /// Configuration Manager (used in tests)
     NakedAgentCfgMgr cfg_mgr_;
 };
@@ -535,7 +485,8 @@ TEST_F(AgentParserTest, configParseSocketDhcp4) {
     ASSERT_TRUE(ctx);
     ConstElementPtr socket = ctx->getControlSocketInfo("dhcp4");
     ASSERT_TRUE(socket);
-    EXPECT_EQ(makeSocketStr("socket-v4"), socket->str());
+    EXPECT_EQ("{ \"socket-name\": \"/tmp/socket-v4\", \"socket-type\": \"unix\" }",
+              socket->str());
     EXPECT_FALSE(ctx->getControlSocketInfo("dhcp6"));
     EXPECT_FALSE(ctx->getControlSocketInfo("d2"));
 }
@@ -550,7 +501,9 @@ TEST_F(AgentParserTest, configParseSocketD2) {
     ASSERT_TRUE(ctx);
     ConstElementPtr socket = ctx->getControlSocketInfo("d2");
     ASSERT_TRUE(socket);
-    EXPECT_EQ(makeSocketStr("socket-d2"), socket->str());
+    EXPECT_EQ("{ \"socket-name\": \"/tmp/socket-d2\", \"socket-type\": \"unix\" }",
+              socket->str());
+
     EXPECT_FALSE(ctx->getControlSocketInfo("dhcp4"));
     EXPECT_FALSE(ctx->getControlSocketInfo("dhcp6"));
 }
@@ -565,7 +518,8 @@ TEST_F(AgentParserTest, configParseSocketDhcp6) {
     ASSERT_TRUE(ctx);
     ConstElementPtr socket = ctx->getControlSocketInfo("dhcp6");
     ASSERT_TRUE(socket);
-    EXPECT_EQ(makeSocketStr("socket-v6"), socket->str());
+    EXPECT_EQ("{ \"socket-name\": \"/tmp/socket-v6\", \"socket-type\": \"unix\" }",
+              socket->str());
     EXPECT_FALSE(ctx->getControlSocketInfo("dhcp4"));
     EXPECT_FALSE(ctx->getControlSocketInfo("d2"));
 }
@@ -580,11 +534,14 @@ TEST_F(AgentParserTest, configParse3Sockets) {
     ConstElementPtr socket4 = ctx->getControlSocketInfo("dhcp4");
     ConstElementPtr socket6 = ctx->getControlSocketInfo("dhcp6");
     ASSERT_TRUE(socket2);
-    EXPECT_EQ(makeSocketStr("socket-d2"), socket2->str());
+    EXPECT_EQ("{ \"socket-name\": \"/tmp/socket-d2\", \"socket-type\": \"unix\" }",
+              socket2->str());
     ASSERT_TRUE(socket4);
-    EXPECT_EQ(makeSocketStr("socket-v4"), socket4->str());
+    EXPECT_EQ("{ \"socket-name\": \"/tmp/socket-v4\", \"socket-type\": \"unix\" }",
+              socket4->str());
     ASSERT_TRUE(socket6);
-    EXPECT_EQ(makeSocketStr("socket-v6"), socket6->str());
+    EXPECT_EQ("{ \"socket-name\": \"/tmp/socket-v6\", \"socket-type\": \"unix\" }",
+              socket6->str());
 }
 
 // This test checks that the config file with hook library specified can be
@@ -592,8 +549,6 @@ TEST_F(AgentParserTest, configParse3Sockets) {
 // name. In particular, it checks if such a library exists. Therefore we
 // can't use AGENT_CONFIGS[4] as is, but need to run it through path replacer.
 TEST_F(AgentParserTest, configParseHooks) {
-    setHooksTestPath();
-
     // Create the configuration with proper lib path.
     std::string cfg = pathReplacer(AGENT_CONFIGS[4], CALLOUT_LIBRARY);
     // The configuration should be successful.
@@ -674,14 +629,23 @@ TEST_F(AgentParserTest, comments) {
     ASSERT_TRUE(ctx6->get("version"));
     EXPECT_EQ("1", ctx6->get("version")->str());
 
-    // Check authentication comment.
-    const HttpAuthConfigPtr& auth = agent_ctx->getAuthConfig();
-    ASSERT_TRUE(auth);
-    ConstElementPtr ctx7 = auth->getContext();
+    // Check HTTP header comment.
+    const CfgHttpHeaders& headers = agent_ctx->getHttpHeaders();
+    ASSERT_EQ(1, headers.size());
+    ConstElementPtr ctx7 = headers[0].getContext();
     ASSERT_TRUE(ctx7);
     ASSERT_EQ(1, ctx7->size());
     ASSERT_TRUE(ctx7->get("comment"));
-    EXPECT_EQ("\"basic HTTP authentication\"", ctx7->get("comment")->str());
+    EXPECT_EQ("\"HSTS header\"", ctx7->get("comment")->str());
+
+    // Check authentication comment.
+    const HttpAuthConfigPtr& auth = agent_ctx->getAuthConfig();
+    ASSERT_TRUE(auth);
+    ConstElementPtr ctx8 = auth->getContext();
+    ASSERT_TRUE(ctx8);
+    ASSERT_EQ(1, ctx8->size());
+    ASSERT_TRUE(ctx8->get("comment"));
+    EXPECT_EQ("\"basic HTTP authentication\"", ctx8->get("comment")->str());
 
     // Check basic HTTP authentication client comment.
     const BasicHttpAuthConfigPtr& basic_auth =
@@ -689,18 +653,18 @@ TEST_F(AgentParserTest, comments) {
     ASSERT_TRUE(basic_auth);
     auto clients = basic_auth->getClientList();
     ASSERT_EQ(2, clients.size());
-    ConstElementPtr ctx8 = clients.front().getContext();
-    ASSERT_TRUE(ctx8);
-    ASSERT_EQ(1, ctx8->size());
-    ASSERT_TRUE(ctx8->get("comment"));
-    EXPECT_EQ("\"foo is authorized\"", ctx8->get("comment")->str());
-
-    // Check basic HTTP authentication client user context.
-    ConstElementPtr ctx9 = clients.back().getContext();
+    ConstElementPtr ctx9 = clients.front().getContext();
     ASSERT_TRUE(ctx9);
     ASSERT_EQ(1, ctx9->size());
-    ASSERT_TRUE(ctx9->get("no password"));
-    EXPECT_EQ("true", ctx9->get("no password")->str());
+    ASSERT_TRUE(ctx9->get("comment"));
+    EXPECT_EQ("\"foo is authorized\"", ctx9->get("comment")->str());
+
+    // Check basic HTTP authentication client user context.
+    ConstElementPtr ctx10 = clients.back().getContext();
+    ASSERT_TRUE(ctx10);
+    ASSERT_EQ(1, ctx10->size());
+    ASSERT_TRUE(ctx10->get("no password"));
+    EXPECT_EQ("true", ctx10->get("no password")->str());
 }
 
 // This test checks if a config with TLS parameters is parsed properly.
