@@ -1,4 +1,4 @@
-// Copyright (C) 2012-2025 Internet Systems Consortium, Inc. ("ISC")
+// Copyright (C) 2012-2024 Internet Systems Consortium, Inc. ("ISC")
 //
 // This Source Code Form is subject to the terms of the Mozilla Public
 // License, v. 2.0. If a copy of the MPL was not distributed with this
@@ -72,38 +72,6 @@ public:
     /// @param exit_value integer value to the process should exit with.
     virtual void shutdownServer(int exit_value);
 
-    /// @brief Command processor
-    ///
-    /// This method is uniform for all config backends. It processes received
-    /// command (as a string + JSON arguments). Internally, it's just a
-    /// wrapper that calls process*Command() methods and catches exceptions
-    /// in them.
-    ///
-    /// Currently supported commands are:
-    /// - shutdown
-    /// - libreload
-    /// - config-reload
-    /// - config-set
-    /// - config-get
-    /// - config-hash-get
-    /// - config-test
-    /// - dhcp-disable
-    /// - dhcp-enable
-    /// - version-get
-    /// - build-report
-    /// - leases-reclaim
-    /// - config-write
-    /// ...
-    ///
-    /// @note It never throws.
-    ///
-    /// @param command Text representation of the command (e.g. "shutdown")
-    /// @param args Optional parameters
-    ///
-    /// @return status of the command
-    static isc::data::ConstElementPtr
-    processCommand(const std::string& command, isc::data::ConstElementPtr args);
-
     /// @brief Configuration processor
     ///
     /// This is a method for handling incoming configuration updates.
@@ -168,19 +136,6 @@ private:
     commandShutdownHandler(const std::string& command,
                            isc::data::ConstElementPtr args);
 
-    /// @brief Handler for processing 'libreload' command
-    ///
-    /// This handler processes libreload command, which unloads all hook
-    /// libraries and reloads them.
-    ///
-    /// @param command (parameter ignored)
-    /// @param args (parameter ignored)
-    ///
-    /// @return status of the command
-    isc::data::ConstElementPtr
-    commandLibReloadHandler(const std::string& command,
-                            isc::data::ConstElementPtr args);
-
     /// @brief Handler for processing 'config-reload' command
     ///
     /// This handler processes config-reload command, which processes
@@ -224,9 +179,9 @@ private:
     /// current configuration to disk. This command takes one optional
     /// parameter called filename. If specified, the current configuration
     /// will be written to that file. If not specified, the file used during
-    /// Kea start-up will be used. To avoid any exploits, the target
-    /// directory must be the same as a security measure against
-    /// exploiting file writes remotely.
+    /// Kea start-up will be used. To avoid any exploits, the path is
+    /// always relative and .. is not allowed in the filename. This is
+    /// a security measure against exploiting file writes remotely.
     ///
     /// @param command (ignored)
     /// @param args may contain optional string argument filename
@@ -324,6 +279,32 @@ private:
     commandLeasesReclaimHandler(const std::string& command,
                                 isc::data::ConstElementPtr args);
 
+    /// @brief Handler for processing 'subnet4-select-test' command
+    ///
+    /// This handler processes subnet4-select-test command, which returns
+    /// the result of DHCPv4 subnet selected.
+    ///
+    /// @param command (parameter ignored)
+    /// @param args arguments map { <selector>: <value> }
+    ///
+    /// @return status of the command with the selection result
+    isc::data::ConstElementPtr
+    commandSubnet4SelectTestHandler(const std::string& command,
+                                    isc::data::ConstElementPtr args);
+
+    /// @brief Handler for processing 'subnet4o6-select-test' command
+    ///
+    /// This handler processes subnet4o6-select-test command, which returns
+    /// the result of DHCP4o6 subnet selected.
+    ///
+    /// @param command (parameter ignored)
+    /// @param args arguments map { <selector>: <value> }
+    ///
+    /// @return status of the command with the selection result
+    isc::data::ConstElementPtr
+    commandSubnet4o6SelectTestHandler(const std::string& command,
+                                      isc::data::ConstElementPtr args);
+
     /// @brief handler for server-tag-get command
     ///
     /// This method handles the server-tag-get command, which retrieves
