@@ -22,6 +22,7 @@
 
 #ifdef HAVE_MYSQL
 #include <mysql/testutils/mysql_schema.h>
+#include <hooks/dhcp/mysql/mysql_lease_mgr.h>
 #endif
 
 #include <log/logger_support.h>
@@ -44,6 +45,7 @@ using namespace isc;
 using namespace isc::asiolink;
 using namespace isc::config;
 using namespace isc::data;
+using namespace isc::db;
 
 #ifdef HAVE_MYSQL
 using namespace isc::db::test;
@@ -173,7 +175,7 @@ typedef boost::shared_ptr<TestCBControlDHCPv6> TestCBControlDHCPv6Ptr;
 ///
 /// Exposes internal fields and installs stub implementation of the
 /// @c CBControlDHCPv6 object.
-class NakedControlledDhcpv6Srv: public ControlledDhcpv6Srv {
+class NakedControlledDhcpv6Srv : public ControlledDhcpv6Srv {
 public:
 
     /// @brief Constructor.
@@ -185,7 +187,12 @@ public:
     }
 };
 
-
+/// @brief test class for Kea configuration backend.
+///
+/// This class is used for testing Kea configuration backend.
+/// It is very simple and currently focuses on reading
+/// config file from disk. It is expected to be expanded in the
+/// near future.
 class JSONFileBackendTest : public dhcp::test::BaseServerTest {
 public:
     JSONFileBackendTest() {
@@ -286,7 +293,6 @@ public:
         EXPECT_EQ(0, cb_control->getDatabaseCurrentConfigFetchCalls());
         EXPECT_EQ(1, cb_control->getDatabaseStagingConfigFetchCalls());
 
-
         if (call_command) {
             // The case where there is no backend is tested in the
             // controlled server tests so we have only to verify
@@ -297,9 +303,8 @@ public:
             EXPECT_EQ(cb_control->getDatabaseCurrentConfigFetchCalls(), 0);
             EXPECT_EQ(cb_control->getDatabaseStagingConfigFetchCalls(), 1);
 
-            ConstElementPtr result =
-                ControlledDhcpv6Srv::processCommand("config-backend-pull",
-                                                    ConstElementPtr());
+            ConstElementPtr list_cmds = createCommand("config-backend-pull");
+            ConstElementPtr result = CommandMgr::instance().processCommand(list_cmds);
             EXPECT_EQ(cb_control->getDatabaseTotalConfigFetchCalls(), 2);
             std::string expected;
 
@@ -797,7 +802,6 @@ TEST_F(JSONFileBackendTest, timers) {
                                        duid_expired, 1, 50, 60, SubnetID(1)));
     lease_expired->cltt_ = time(NULL) - 100;
 
-
     // Create expired-reclaimed lease. The lease has expired 1000 - 60 seconds
     // ago. It should be removed from the lease database when the "flush" timer
     // goes off.
@@ -984,6 +988,9 @@ public:
     /// reconfiguration.
     void testBackendReconfiguration(const std::string& backend_first,
                                     const std::string& backend_second);
+
+    /// @brief Initializer.
+    MySqlLeaseMgrInit init_;
 };
 
 std::string
@@ -1063,7 +1070,6 @@ testBackendReconfiguration(const std::string& backend_first,
               LeaseMgrFactory::instance().getType());
 }
 
-
 // This test verifies that backend specification can be added on
 // server reconfiguration.
 TEST_F(JSONFileBackendMySQLTest, reconfigureBackendUndefinedToMySQL) {
