@@ -279,11 +279,7 @@ public:
 
     virtual ~NameChangeTransactionTest() {
         timer_->cancel();
-        io_service_->restart();
-        try {
-            io_service_->poll();
-        } catch (...) {
-        }
+        io_service_->stopAndPoll();
         io_service_.reset(new IOService());
         timer_.reset(new IntervalTimer(io_service_));
     }
@@ -578,7 +574,7 @@ TEST_F(NameChangeTransactionTest, responseString) {
     EXPECT_EQ("IO_STOPPED", name_change_->responseString());
 
     ASSERT_NO_THROW(name_change_->setDnsUpdateStatus(DNSClient::
-                                                    INVALID_RESPONSE));
+                                                     INVALID_RESPONSE));
     EXPECT_EQ("INVALID_RESPONSE", name_change_->responseString());
 
     ASSERT_NO_THROW(name_change_->setDnsUpdateStatus(DNSClient::OTHER));
@@ -1263,4 +1259,4 @@ TEST_F(NameChangeTransactionTest, addPtrRdata) {
     EXPECT_EQ(ncr->getFqdn(), rdata_it->getCurrent().toText());
 }
 
-}; // anonymous namespace
+}  // anonymous namespace
