@@ -50,7 +50,8 @@ extern const isc::log::MessageID DHCPSRV_CFGMGR_USE_UNICAST;
 extern const isc::log::MessageID DHCPSRV_CLASS_WITH_ADDITIONAL_AND_LIFETIMES;
 extern const isc::log::MessageID DHCPSRV_CLIENT_CLASS_DEPRECATED;
 extern const isc::log::MessageID DHCPSRV_CLOSE_DB;
-extern const isc::log::MessageID DHCPSRV_DDNS_TTL_PERCENT_TOO_SMALL;
+extern const isc::log::MessageID DHCPSRV_DDNS_TTL_TOO_LARGE;
+extern const isc::log::MessageID DHCPSRV_DDNS_TTL_TOO_SMALL;
 extern const isc::log::MessageID DHCPSRV_DHCP4O6_RECEIVED_BAD_PACKET;
 extern const isc::log::MessageID DHCPSRV_DHCP_DDNS_ERROR_EXCEPTION;
 extern const isc::log::MessageID DHCPSRV_DHCP_DDNS_HANDLER_NULL;
