@@ -77,8 +77,7 @@ TEST(SharedNetwork4Test, defaults) {
     EXPECT_TRUE(network->getIface().unspecified());
     EXPECT_TRUE(network->getIface().empty());
 
-    EXPECT_TRUE(network->getClientClass().unspecified());
-    EXPECT_TRUE(network->getClientClass().empty());
+    EXPECT_TRUE(network->getClientClasses().empty());
 
     EXPECT_TRUE(network->getValid().unspecified());
     EXPECT_EQ(0, network->getValid().get());
@@ -392,7 +391,7 @@ TEST(SharedNetwork4Test, getNextSubnet) {
     // Perform the test 3 times where each subnet belonging to the shared
     // network is treated as a "first" subnet in the call to getNextSubnet.
     for (auto i = 0; i < subnets.size(); ++i) {
-        Subnet4Ptr s = subnets[i];
+        ConstSubnet4Ptr s = subnets[i];
 
         // Iterate over the subnets starting from the subnet with index i.
         for (auto j = 0; j < subnets.size(); ++j) {
@@ -464,7 +463,7 @@ TEST(SharedNetwork4Test, getPreferredSubnet) {
             << " to shared network";
     }
 
-    Subnet4Ptr preferred;
+    ConstSubnet4Ptr preferred;
 
     // Initially, for every subnet we should get the same subnet as the preferred
     // one, because none of them have been used.
@@ -563,7 +562,7 @@ TEST(SharedNetwork4Test, getPreferredSubnetMultiThreading) {
             << " to shared network";
     }
 
-    Subnet4Ptr preferred;
+    ConstSubnet4Ptr preferred;
 
     // Initially, for every subnet we should get the same subnet as the preferred
     // one, because none of them have been used.
@@ -829,8 +828,7 @@ TEST(SharedNetwork6Test, defaults) {
     EXPECT_TRUE(network->getIface().unspecified());
     EXPECT_TRUE(network->getIface().empty());
 
-    EXPECT_TRUE(network->getClientClass().unspecified());
-    EXPECT_TRUE(network->getClientClass().empty());
+    EXPECT_TRUE(network->getClientClasses().empty());
 
     EXPECT_TRUE(network->getValid().unspecified());
     EXPECT_EQ(0, network->getValid().get());
@@ -1142,7 +1140,7 @@ TEST(SharedNetwork6Test, getNextSubnet) {
     // Perform the test 3 times where each subnet belonging to the shared
     // network is treated as a "first" subnet in the call to getNextSubnet.
     for (auto i = 0; i < subnets.size(); ++i) {
-        Subnet6Ptr s = subnets[i];
+        ConstSubnet6Ptr s = subnets[i];
 
         // Iterate over the subnets starting from the subnet with index i.
         for (auto j = 0; j < subnets.size(); ++j) {
@@ -1199,7 +1197,7 @@ TEST(SharedNetwork6Test, getPreferredSubnet) {
             << " to shared network";
     }
 
-    Subnet6Ptr preferred;
+    ConstSubnet6Ptr preferred;
 
     // Initially, for every subnet we should get the same subnet as the preferred
     // one, because none of them have been used.
@@ -1303,7 +1301,7 @@ TEST(SharedNetwork6Test, getPreferredSubnetMultiThreading) {
             << " to shared network";
     }
 
-    Subnet6Ptr preferred;
+    ConstSubnet6Ptr preferred;
 
     // Initially, for every subnet we should get the same subnet as the preferred
     // one, because none of them have been used.
