@@ -10,7 +10,7 @@
 #include <cc/dhcp_config_error.h>
 #include <hooks/hooks_parser.h>
 #include <boost/algorithm/string.hpp>
-#include <util/strutil.h>
+#include <util/str.h>
 #include <vector>
 
 using namespace std;
@@ -23,6 +23,8 @@ namespace hooks {
 
 // @todo use the flat style, split into list and item
 
+string HooksLibrariesParser::default_hooks_path_ = string(DEFAULT_HOOKS_PATH);
+
 void
 HooksLibrariesParser::parse(HooksConfig& libraries, ConstElementPtr value) {
     // Initialize.
@@ -77,6 +79,11 @@ HooksLibrariesParser::parse(HooksConfig& libraries, ConstElementPtr value) {
                         entry_item.second->getPosition() << ")");
                 }
 
+                // If only the name of the library was provided, add the full path.
+                if (libname.find("/") == string::npos) {
+                    libname = HooksLibrariesParser::default_hooks_path_ + "/" + libname;
+                }
+
                 // Note we have found the library name.
                 lib_found = true;
                 continue;
