@@ -1,4 +1,4 @@
-// Copyright (C) 2012-2024 Internet Systems Consortium, Inc. ("ISC")
+// Copyright (C) 2012-2025 Internet Systems Consortium, Inc. ("ISC")
 //
 // This Source Code Form is subject to the terms of the Mozilla Public
 // License, v. 2.0. If a copy of the MPL was not distributed with this
@@ -8,6 +8,7 @@
 
 #include <asiolink/io_service.h>
 #include <asiolink/process_spawn.h>
+#include <cc/default_credentials.h>
 #include <database/database_connection.h>
 #include <database/db_log.h>
 #include <exceptions/exceptions.h>
@@ -24,6 +25,7 @@
 
 using namespace isc;
 using namespace isc::asiolink;
+using namespace isc::data;
 using namespace std;
 
 namespace isc {
@@ -96,6 +98,10 @@ MySqlConnection::openDatabase() {
     } catch (...) {
         // No password.  Fine, we'll use NULL
     }
+    if (password) {
+        // Refuse default password.
+        DefaultCredentials::check(spassword);
+    }
 
     const char* name = NULL;
     string sname;
@@ -320,12 +326,13 @@ std::pair<uint32_t, uint32_t>
 MySqlConnection::getVersion(const ParameterMap& parameters,
                             const IOServiceAccessorPtr& ac,
                             const DbCallback& cb,
-                            const string& timer_name) {
+                            const string& timer_name,
+                            unsigned int id) {
     // Get a connection.
     MySqlConnection conn(parameters, ac, cb);
 
     if (!timer_name.empty()) {
-        conn.makeReconnectCtl(timer_name);
+        conn.makeReconnectCtl(timer_name, id);
     }
 
     // Open the database.
